summaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
Diffstat (limited to 'tests')
-rw-r--r--tests/annotations/tests.py20
1 files changed, 18 insertions, 2 deletions
diff --git a/tests/annotations/tests.py b/tests/annotations/tests.py
index c39e8d3fbe..0cdc9178b0 100644
--- a/tests/annotations/tests.py
+++ b/tests/annotations/tests.py
@@ -1,10 +1,13 @@
import datetime
from decimal import Decimal
+from unittest import skipIf
from django.core.exceptions import FieldDoesNotExist, FieldError
+from django.db import connection
from django.db.models import (
- BooleanField, CharField, Count, DateTimeField, ExpressionWrapper, F, Func,
- IntegerField, NullBooleanField, OuterRef, Q, Subquery, Sum, Value,
+ BooleanField, CharField, Count, DateTimeField, Exists, ExpressionWrapper,
+ F, Func, IntegerField, Max, NullBooleanField, OuterRef, Q, Subquery, Sum,
+ Value,
)
from django.db.models.expressions import RawSQL
from django.db.models.functions import Length, Lower
@@ -619,3 +622,16 @@ class NonAggregateAnnotationTestCase(TestCase):
total_books=Subquery(long_books_qs, output_field=IntegerField()),
).values('name')
self.assertCountEqual(publisher_books_qs, [{'name': 'Sams'}, {'name': 'Morgan Kaufmann'}])
+
+ @skipIf(connection.vendor == 'oracle', 'See https://code.djangoproject.com/ticket/31584')
+ def test_annotation_exists_aggregate_values_chaining(self):
+ qs = Book.objects.values('publisher').annotate(
+ has_authors=Exists(Book.authors.through.objects.filter(book=OuterRef('pk'))),
+ max_pubdate=Max('pubdate'),
+ ).values_list('max_pubdate', flat=True).order_by('max_pubdate')
+ self.assertCountEqual(qs, [
+ datetime.date(1991, 10, 15),
+ datetime.date(2008, 3, 3),
+ datetime.date(2008, 6, 23),
+ datetime.date(2008, 11, 3),
+ ])